<?php

namespace Drupal\scribit_pro\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class DashboardController.
 */
class DashboardController extends ControllerBase {

  /**
   * Drupal\scribit_pro\ApiService definition.
   *
   * @var \Drupal\scribit_pro\ApiService
   */
  protected $api;

  /**
   * Scribit Pro helper service.
   *
   * @var \Drupal\Scribit_pro\HelperService
   */
  protected $helper;

  /**
   * Drupal\Core\Render\Renderer definition.
   *
   * @var \Drupal\Core\Render\Renderer
   */
  protected $renderer;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->api = $container->get('scribit_pro.api');
    $instance->helper = $container->get('scribit_pro.helper');
    $instance->renderer = $container->get('renderer');

    return $instance;
  }

  /**
   * Content.
   *
   * @return string
   *   Return Hello string.
   */
  public function content() {
    $content = [];

    $content['account'] = [
      '#type' => 'details',
      '#title' => $this->t('Account'),
    ];

    if ($this->helper->hasCredentials() && ($user = $this->helper->getLocalProUser())) {

      $content['account']['info'] = [
        '#type' => 'table',
        '#header' => [
          $this->t('Username'),
          $this->t('Email'),
        ],
        '#rows' => [
          [
            'username' => $user->username,
            'email' => $user->email,
          ],
        ],
      ];
    }
    else {
      $content['account']['info'] = [
        '#type' => 'markup',
        '#markup' => $this->t('Please login first.'),
      ];
    }

    // $content['videos'] = [
    //   '#type' => 'details',
    //   '#title' => $this->t('Videos'),
    //   '#group' => 'tabs',
    // ];

    // try {
    //   $videos = $this->api->getProjects();
    // }
    // catch (\Throwable $th) {
    //   $x = 1;
    // }

    // $rows = [];

    // if (isset($videos['body']) && !empty($videos['body'])) {
    //   foreach ($videos['body'] as $video) {
    //     $video_link = [
    //       '#type' => 'link',
    //       '#title' => $video->videos[0]->link,
    //       '#url' => Url::fromUri($video->videos[0]->link),
    //       '#attributes' => [
    //         'target' => '_blank',
    //       ],
    //     ];

    //     $rows[] = [
    //       'title' => $video->title,
    //       'description' => $video->video_description,
    //       'video' => $this->renderer->render($video_link),
    //     ];
    //   }

    //   $header = [
    //     $this->t('Title'),
    //     $this->t('Description'),
    //     $this->t('Video'),
    //   ];

    //   $content['videos']['table'] = [
    //     '#type' => 'table',
    //     '#header' => $header,
    //     '#rows' => $rows,
    //   ];
    // }

    // }
    // else {
    //   $content[] = $this->noCredentials();
    // }

    return $content;
  }

  /**
   * Undocumented function
   *
   * @return void
   */
  public function noCredentials() {
    return [
      'text' => [
        '#type' => 'inline_template',
        '#template' => '<div class="">{{ text }}</div>',
      ],
      'link' => [
        '#title' => $this->t('Login to Scribi Pro'),
        '#type' => 'link',
        '#link' => Url::fromRoute('scribit_pro.config'),
        '#attributes' => [
          'class' => [
            'button',
            'button--primary',
          ],
        ],
      ],
    ];
  }

  public function createEmbed($indetifier, $scribit_id) {
    $embed = [
      '#type' => 'inline_template',
      '#template' => '<textarea><iframe scrolling="no" frameborder="0" src="https://dashboard.scribit.pro/videoplayer/index.html?video=https://storage.googleapis.com/scribit-pro-hosting/prod/generated-output/7e81b83a-fcc9-4288-9ff3-60b4a98fa8a8/7e81b83a-fcc9-4288-9ff3-60b4a98fa8a8.mp4&subtitles=https://storage.googleapis.com/scribit-pro-hosting/prod/generated-output/7e81b83a-fcc9-4288-9ff3-60b4a98fa8a8/7e81b83a-fcc9-4288-9ff3-60b4a98fa8a8.srt&audioDescription=https://storage.googleapis.com/scribit-pro-hosting/prod/generated-output/7e81b83a-fcc9-4288-9ff3-60b4a98fa8a8/7e81b83a-fcc9-4288-9ff3-60b4a98fa8a8.mp3&alternativeText=https://storage.googleapis.com/scribit-pro-hosting/prod/generated-output/7e81b83a-fcc9-4288-9ff3-60b4a98fa8a8/alternative-7e81b83a-fcc9-4288-9ff3-60b4a98fa8a8.txt&thumbnail=https://storage.googleapis.com/scribit-pro-hosting/prod/generated-output/7e81b83a-fcc9-4288-9ff3-60b4a98fa8a8/7e81b83a-fcc9-4288-9ff3-60b4a98fa8a8.jpg" style="min-width:300px;min-height:450px;"></iframe></textarea>'
    ];
  }

}
