<?php

namespace Drupal\scribit_pro\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class ConfigForm.
 */
class ConfigForm extends ConfigFormBase {

  /**
   * Drupal\key\KeyRepositoryInterface definition.
   *
   * @var \Drupal\key\KeyRepositoryInterface
   */
  protected $keyRepository;

  /**
   * Scribit Pro helper.
   *
   * @var \Drupal\scribit_pro\HelperService
   */
  protected $helper;

  /**
   * Scribit Pro user.
   *
   * @var object
   */
  protected $user;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->keyRepository = $container->get('key.repository');
    $instance->helper = $container->get('scribit_pro.helper');

    return $instance;
  }

  /**
   * {@inheritDoc}
   */
  protected function getEditableConfigNames() {
    return ['scribit_pro.config'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('scribit_pro.config');

    $email = $config->get('email');
    $password = $config->get('password');

    $input = $form_state->getUserInput();

    $set_email = isset($input['email']) ? $input['email'] : NULL;
    $set_password = isset($input['password']) ? $input['password'] : NULL;

    if (($email || $set_email) && ($password || $set_password) && $user = $this->helper->getScribitProUserLoginStatus($set_email, $set_password)) {
      $form['user_status'] = [
        '#type' => 'table',
        '#header' => [
          'username' => $this->t('Username'),
          'email' => $this->t('Email'),
        ],
        '#rows' => [
          [
            $user->username,
            $user->email,
          ],
        ],
      ];
    }
    else {
      $form['login_message'] = [
        '#type' => 'item',
        '#markup' => '<p>' . $this->t('Login using your Scribit Pro credentials.') . '</p>',
        '#weight' => -1,
      ];
    }

    $form['email'] = [
      '#type' => 'key_select',
      '#title' => $this->t('Email'),
      '#description' => $this->t('Email'),
      '#weight' => '0',
      '#default_value' => $email ? $email : NULL,
    ];

    $form['password'] = [
      '#type' => 'key_select',
      '#title' => $this->t('Password'),
      '#description' => $this->t('Password'),
      '#weight' => '1',
      '#default_value' => $password ? $password : NULL,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
      '#weight' => '2',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (!$form_state->getValues('email')) {
      $form_state->setErrorByName('email', $this->t('Email must be set'));
    }
    if (!$form_state->getValues('password')) {
      $form_state->setErrorByName('password', $this->t('Password must be set'));
    }

    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $values = $form_state->getValues();

    $email_key = $values['email'];
    $password_key = $values['password'];

    $this->config('scribit_pro.config')
      ->set('email', $email_key)
      ->set('password', $password_key)
      ->save();

    if ($user = $this->helper->getScribitProUserLoginStatus($email_key, $password_key)) {
      $this->user = $user;
    }
    $x = 1;

  }

}
